@@ -1,12 +1,16 @@
+from category.models import Category, Tag
 from django.contrib import admin
 
-from category.models import Category, Tag
 
 class CategoryAdmin(admin.ModelAdmin):
     prepopulated_fields = {"slug": ("title",)}
+    list_display = ('title', 'subtitle', 'slug')
+    list_filter = ('sites',)
+
 
 class TagAdmin(admin.ModelAdmin):
     prepopulated_fields = {"slug": ("title",)}
 
+
 admin.site.register(Category, CategoryAdmin)
 admin.site.register(Tag, TagAdmin)
